Function get_library
fn get_library() -> Option<Arc<SharedLibrary>>
Returns the library instance stored in TLS.
This functions allows for sharing library instances between threads.
get_libraryfn get_library() -> Option<Arc<SharedLibrary>>
Returns the library instance stored in TLS.
This functions allows for sharing library instances between threads.