Function is_loaded
fn is_loaded() -> bool
Returns whether a libclang shared library is loaded on this thread.
is_loadedfn is_loaded() -> bool
Returns whether a libclang shared library is loaded on this thread.