Function unload
fn unload() -> Result<(), String>
Unloads the libclang shared library in use in the current thread.
Failures
- a
libclangshared library is not in use in the current thread
unloadfn unload() -> Result<(), String>
Unloads the libclang shared library in use in the current thread.
libclang shared library is not in use in the current thread