Struct SharedLibrary
struct SharedLibrary { ... }
A dynamically loaded instance of the libclang library.
Fields
functions: Functions
Implementations
impl SharedLibrary
fn path(self: &Self) -> &PathReturns the path to this
libclangshared library.fn version(self: &Self) -> Option<Version>Returns the (minimum) version of this
libclangshared library.If this returns
None, it indicates that the version is too old to be supported by this crate (i.e.,3.4or earlier). If the version of this shared library is more recent than that fully supported by this crate, the most recent fully supported version will be returned.
impl Debug for SharedLibrary
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for SharedLibrary
impl RefUnwindSafe for SharedLibrary
impl Send for SharedLibrary
impl Sync for SharedLibrary
impl Unpin for SharedLibrary
impl UnsafeUnpin for SharedLibrary
impl UnwindSafe for SharedLibrary
impl<T> Any for SharedLibrary
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for SharedLibrary
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for SharedLibrary
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for SharedLibrary
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for SharedLibrary
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for SharedLibrary
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for SharedLibrary
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>