Function load_manually
fn load_manually() -> Result<SharedLibrary, String>
Loads a libclang shared library and returns the library instance.
This function does not attempt to load any functions from the shared library. The caller is responsible for loading the functions they require.
Failures
- a
libclangshared library could not be found - the
libclangshared library could not be opened