Struct clang_sys::SharedLibrary [−][src]
pub struct SharedLibrary {
pub functions: Functions,
// some fields omitted
}Expand description
A dynamically loaded instance of the libclang library.
Fields
functions: FunctionsImplementations
Returns the (minimum) version of this libclang shared library.
If this returns None, it indicates that the version is too old
to be supported by this crate (i.e., 3.4 or earlier). If the
version of this shared library is more recent than that fully
supported by this crate, the most recent fully supported version
will be returned.