Struct Clang
struct Clang { ... }
A clang executable.
Fields
path: PathBufThe path to this
clangexecutable.version: Option<CXVersion>The version of this
clangexecutable if it could be parsed.c_search_paths: Option<Vec<PathBuf>>The directories searched by this
clangexecutable for C headers if they could be parsed.cpp_search_paths: Option<Vec<PathBuf>>The directories searched by this
clangexecutable for C++ headers if they could be parsed.
Implementations
impl Clang
fn find(path: Option<&Path>, args: &[String]) -> Option<Clang>Returns a
clangexecutable if one can be found.If the
CLANG_PATHenvironment variable is set, that is the instance ofclangused. Otherwise, a series of directories are searched. First, if a path is supplied, that is the first directory searched. Then, the directory returned byllvm-config --bindiris searched. On macOS systems,xcodebuild -find clangwill next be queried. Last, the directories in the system'sPATHare searched.
impl Clone for Clang
fn clone(self: &Self) -> Clang
impl Debug for Clang
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Clang
impl RefUnwindSafe for Clang
impl Send for Clang
impl Sync for Clang
impl Unpin for Clang
impl UnsafeUnpin for Clang
impl UnwindSafe for Clang
impl<T> Any for Clang
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Clang
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Clang
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Clang
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Clang
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Clang
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Clang
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Clang
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Clang
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>